import { Command } from "ckeditor5/src/core";

export default class InsertAddressCommand extends Command {
  execute(query) {
    const { editor } = this;
    const { model } = editor;
    const config = this.editor.config.get('address_suggestion');
    let url = config['endpoint'] + '?q=' + query;
    fetch(url).then(function (response) {
      if (!response.ok) {
        throw new Error('Request error: ' + response.status);
      }
      return response.json();
    }).then(function (data) {
      let addresseText = data[0].label;
      let longtitude = data[0].location.longitude;
      let latitude = data[0].location.latitude;
      let langCode = drupalSettings.path.currentLanguage;
      let address = `<address class='address-suggestion'>${addresseText}</address>`;
      let srcMap = 'https://maps.google.com/maps?t=&z=14&ie=UTF8&iwloc=B&output=embed&hl=' + langCode + '&q=' + addresseText;
      let map = `<iframe src="${srcMap}" class="address-suggestion"
   width="100%" height="450" allowfullscreen="" loading="lazy"
   referrerpolicy="no-referrer-when-downgrade">
</iframe>`;
      model.change(writer => {
        const content = writer.createElement('addressSuggestion');
        const docFrag = writer.createDocumentFragment();
        const viewFragment = editor.data.processor.toView(map + address);
        const modelFragment = editor.data.toModel(viewFragment);
        writer.append(content, docFrag);
        writer.append(modelFragment, content);
        model.insertContent(docFrag);
      });
    });
  }

  refresh() {
    const {model} = this.editor;
    const {selection} = model.document;
    const allowedIn = model.schema.findAllowedParent(
      selection.getFirstPosition(),
      'addressSuggestion',
    );
    this.isEnabled = allowedIn !== null;
  }

}

